Utility functions and classes
=============================

Functions
---------
.. autofunction:: everybeam.load_telescope

.. autofunction:: everybeam.cart2thetaphi

.. autofunction:: everybeam.thetaphi2cart

Classes
-------
.. autoclass:: everybeam.GridSettings
    :members:

.. autoclass:: everybeam.Options
    :members:

Enums
-----
.. autodata:: everybeam.ElementResponseModel

.. autodata:: everybeam.BeamMode

.. autodata:: everybeam.BeamNormalisationMode
